@@ -1,11 +1,10 @@
-from __future__ import print_function, absolute_import, unicode_literals
 from zope.interface import implementer
 from attr import attrs, attrib
-from attr.validators import provides
 from automat import MethodicalMachine
 from . import _interfaces
 from ._nameplate import validate_nameplate
 from .errors import KeyFormatError
+from .util import provides
 
 
 def validate_code(code):
