@@ -1,8 +1,7 @@
-from __future__ import print_function, absolute_import, unicode_literals
 import os
-from six.moves.urllib_parse import urlparse
+from urllib.parse import urlparse
 from attr import attrs, attrib
-from attr.validators import provides, instance_of, optional
+from attr.validators import instance_of, optional
 from zope.interface import implementer
 from twisted.python import log
 from twisted.internet import defer, endpoints, task
@@ -10,7 +9,7 @@ from twisted.application import internet
 from autobahn.twisted import websocket
 from . import _interfaces, errors
 from .util import (bytes_to_hexstr, hexstr_to_bytes, bytes_to_dict,
-                   dict_to_bytes)
+                   dict_to_bytes, provides)
 
 
 class WSClient(websocket.WebSocketClientProtocol):
@@ -81,14 +80,14 @@ class RendezvousConnector(object):
         self._ws = None
         f = WSFactory(self, self._url)
         f.setProtocolOptions(autoPingInterval=60, autoPingTimeout=600)
-        p = urlparse(self._url)
-        ep = self._make_endpoint(p.hostname, p.port or 80)
+        ep = self._make_endpoint(self._url)
         self._connector = internet.ClientService(ep, f)
         faf = None if self._have_made_a_successful_connection else 1
         d = self._connector.whenConnected(failAfterFailures=faf)
         # if the initial connection fails, signal an error and shut down. do
         # this in a different reactor turn to avoid some hazards
         d.addBoth(lambda res: task.deferLater(self._reactor, 0.0, lambda: res))
+        # TODO: use EventualQueue
         d.addErrback(self._initial_connection_failed)
         self._debug_record_inbound_f = None
 
@@ -99,11 +98,16 @@ class RendezvousConnector(object):
         if self._trace:
             self._trace(old_state="", input=what, new_state="")
 
-    def _make_endpoint(self, hostname, port):
+    def _make_endpoint(self, url):
+        p = urlparse(url)
+        tls = (p.scheme == "wss")
+        port = p.port or (443 if tls else 80)
         if self._tor:
-            # TODO: when we enable TLS, maybe add tls=True here
-            return self._tor.stream_via(hostname, port)
-        return endpoints.HostnameEndpoint(self._reactor, hostname, port)
+            return self._tor.stream_via(p.hostname, port, tls=tls)
+        if tls:
+            return endpoints.clientFromString(self._reactor,
+                                              "tls:%s:%s" % (p.hostname, port))
+        return endpoints.HostnameEndpoint(self._reactor, p.hostname, port)
 
     def wire(self, boss, nameplate, mailbox, allocator, lister, terminator):
         self._B = _interfaces.IBoss(boss)
@@ -245,7 +249,7 @@ class RendezvousConnector(object):
 
     # internal
     def _stopped(self, res):
-        self._T.stopped()
+        self._T.stoppedRC()
 
     def _tx(self, mtype, **kwargs):
         assert self._ws
