@@ -1,12 +1,11 @@
-from __future__ import absolute_import, print_function, unicode_literals
-
 from attr import attrib, attrs
-from attr.validators import instance_of, provides
+from attr.validators import instance_of
 from automat import MethodicalMachine
 from zope.interface import implementer
 
 from . import _interfaces
 from ._key import derive_phase_key, encrypt_data
+from .util import provides
 
 
 @attrs
