@@ -1,5 +1,3 @@
-from __future__ import print_function, unicode_literals
-
 import json
 
 from nacl.secret import SecretBox
@@ -7,14 +5,15 @@ from spake2 import SPAKE2_Symmetric
 from twisted.trial import unittest
 from zope.interface import directlyProvides, implementer
 
-import mock
+from unittest import mock
 
 from .. import (__version__, _allocator, _boss, _code, _input, _key, _lister,
                 _mailbox, _nameplate, _order, _receive, _rendezvous, _send,
                 _terminator, errors, timing)
-from .._interfaces import (IAllocator, IBoss, ICode, IInput, IKey, ILister,
-                           IMailbox, INameplate, IOrder, IReceive,
-                           IRendezvousConnector, ISend, ITerminator, IWordlist)
+from .._interfaces import (IAllocator, IBoss, ICode, IDilator, IInput, IKey,
+                           ILister, IMailbox, INameplate, IOrder, IReceive,
+                           IRendezvousConnector, ISend, ITerminator, IWordlist,
+                           ITorManager)
 from .._key import derive_key, derive_phase_key, encrypt_data
 from ..journal import ImmediateJournal
 from ..util import (bytes_to_dict, bytes_to_hexstr, dict_to_bytes,
@@ -392,10 +391,10 @@ class Input(unittest.TestCase):
     def build(self):
         events = []
         i = _input.Input(timing.DebugTiming())
-        c = Dummy("c", events, ICode, "got_nameplate", "finished_input")
-        l = Dummy("l", events, ILister, "refresh")
-        i.wire(c, l)
-        return i, c, l, events
+        code = Dummy("c", events, ICode, "got_nameplate", "finished_input")
+        lister = Dummy("l", events, ILister, "refresh")
+        i.wire(code, lister)
+        return i, code, lister, events
 
     def test_ignore_completion(self):
         i, c, l, events = self.build()
@@ -1220,7 +1219,8 @@ class Terminator(unittest.TestCase):
         rc = Dummy("rc", events, IRendezvousConnector, "stop")
         n = Dummy("n", events, INameplate, "close")
         m = Dummy("m", events, IMailbox, "close")
-        t.wire(b, rc, n, m)
+        d = Dummy("d", events, IDilator, "stop")
+        t.wire(b, rc, n, m, d)
         return t, b, rc, n, m, events
 
     # there are three events, and we need to test all orderings of them
@@ -1229,45 +1229,64 @@ class Terminator(unittest.TestCase):
         input_events = {
             "mailbox": lambda: t.mailbox_done(),
             "nameplate": lambda: t.nameplate_done(),
-            "close": lambda: t.close("happy"),
+            "rc": lambda: t.close("happy"),
         }
         close_events = [
             ("n.close", ),
             ("m.close", "happy"),
         ]
 
+        if ev1 == "mailbox":
+            close_events.remove(("m.close", "happy"))
+        elif ev1 == "nameplate":
+            close_events.remove(("n.close",))
+
         input_events[ev1]()
         expected = []
-        if ev1 == "close":
+        if ev1 == "rc":
             expected.extend(close_events)
         self.assertEqual(events, expected)
         events[:] = []
 
+        if ev2 == "mailbox":
+            close_events.remove(("m.close", "happy"))
+        elif ev2 == "nameplate":
+            close_events.remove(("n.close",))
+
         input_events[ev2]()
         expected = []
-        if ev2 == "close":
+        if ev2 == "rc":
             expected.extend(close_events)
         self.assertEqual(events, expected)
         events[:] = []
 
+        if ev3 == "mailbox":
+            close_events.remove(("m.close", "happy"))
+        elif ev3 == "nameplate":
+            close_events.remove(("n.close",))
+
         input_events[ev3]()
         expected = []
-        if ev3 == "close":
+        if ev3 == "rc":
             expected.extend(close_events)
         expected.append(("rc.stop", ))
         self.assertEqual(events, expected)
         events[:] = []
 
-        t.stopped()
+        t.stoppedRC()
+        self.assertEqual(events, [("d.stop", )])
+        events[:] = []
+
+        t.stoppedD()
         self.assertEqual(events, [("b.closed", )])
 
     def test_terminate(self):
-        self._do_test("mailbox", "nameplate", "close")
-        self._do_test("mailbox", "close", "nameplate")
-        self._do_test("nameplate", "mailbox", "close")
-        self._do_test("nameplate", "close", "mailbox")
-        self._do_test("close", "nameplate", "mailbox")
-        self._do_test("close", "mailbox", "nameplate")
+        self._do_test("mailbox", "nameplate", "rc")
+        self._do_test("mailbox", "rc", "nameplate")
+        self._do_test("nameplate", "mailbox", "rc")
+        self._do_test("nameplate", "rc", "mailbox")
+        self._do_test("rc", "nameplate", "mailbox")
+        self._do_test("rc", "mailbox", "nameplate")
 
     # TODO: test moods
 
@@ -1286,17 +1305,21 @@ class Boss(unittest.TestCase):
                          "closed")
         versions = {"app": "version1"}
         reactor = None
+        eq = None
+        cooperator = None
         journal = ImmediateJournal()
         tor_manager = None
         client_version = ("python", __version__)
         b = MockBoss(wormhole, "side", "url", "appid", versions,
-                     client_version, reactor, journal, tor_manager,
+                     client_version, reactor, eq, cooperator, journal,
+                     tor_manager,
                      timing.DebugTiming())
         b._T = Dummy("t", events, ITerminator, "close")
         b._S = Dummy("s", events, ISend, "send")
         b._RC = Dummy("rc", events, IRendezvousConnector, "start")
         b._C = Dummy("c", events, ICode, "allocate_code", "input_code",
                      "set_code")
+        b._D = Dummy("d", events, IDilator, "got_wormhole_versions", "got_key")
         return b, events
 
     def test_basic(self):
@@ -1324,7 +1347,9 @@ class Boss(unittest.TestCase):
         b.got_message("0", b"msg1")
         self.assertEqual(events, [
             ("w.got_key", b"key"),
+            ("d.got_key", b"key"),
             ("w.got_verifier", b"verifier"),
+            ("d.got_wormhole_versions", {}),
             ("w.got_versions", {}),
             ("w.received", b"msg1"),
         ])
@@ -1529,9 +1554,9 @@ class Rendezvous(unittest.TestCase):
         n = Dummy("n", events, INameplate, "connected", "lost")
         m = Dummy("m", events, IMailbox, "connected", "lost")
         a = Dummy("a", events, IAllocator, "connected", "lost")
-        l = Dummy("l", events, ILister, "connected", "lost")
+        x = Dummy("l", events, ILister, "connected", "lost")
         t = Dummy("t", events, ITerminator)
-        rc.wire(b, n, m, a, l, t)
+        rc.wire(b, n, m, a, x, t)
         return rc, events
 
     def test_basic(self):
@@ -1595,6 +1620,70 @@ class Rendezvous(unittest.TestCase):
             ("a.lost", ),
         ])
 
+    def test_endpoints(self):
+        # parse different URLs and check the tls status of each
+        reactor = object()
+        journal = ImmediateJournal()
+        tor_manager = None
+        client_version = ("python", __version__)
+        rc = _rendezvous.RendezvousConnector(
+            "ws://host:4000/v1", "appid", "side", reactor, journal,
+            tor_manager, timing.DebugTiming(), client_version)
+
+        new_ep = object()
+        with mock.patch("twisted.internet.endpoints.HostnameEndpoint",
+                        return_value=new_ep) as he:
+            ep = rc._make_endpoint("ws://host:4000/v1")
+        self.assertEqual(he.mock_calls, [mock.call(reactor, "host", 4000)])
+        self.assertIs(ep, new_ep)
+
+        new_ep = object()
+        with mock.patch("twisted.internet.endpoints.HostnameEndpoint",
+                        return_value=new_ep) as he:
+            ep = rc._make_endpoint("ws://host/v1")
+        self.assertEqual(he.mock_calls, [mock.call(reactor, "host", 80)])
+        self.assertIs(ep, new_ep)
+
+        new_ep = object()
+        with mock.patch("twisted.internet.endpoints.clientFromString",
+                        return_value=new_ep) as cfs:
+            ep = rc._make_endpoint("wss://host:4000/v1")
+        self.assertEqual(cfs.mock_calls, [mock.call(reactor, "tls:host:4000")])
+        self.assertIs(ep, new_ep)
+
+        new_ep = object()
+        with mock.patch("twisted.internet.endpoints.clientFromString",
+                        return_value=new_ep) as cfs:
+            ep = rc._make_endpoint("wss://host/v1")
+        self.assertEqual(cfs.mock_calls, [mock.call(reactor, "tls:host:443")])
+        self.assertIs(ep, new_ep)
+
+        tor_manager = mock.Mock()
+        directlyProvides(tor_manager, ITorManager)
+        rc = _rendezvous.RendezvousConnector(
+            "ws://host:4000/v1", "appid", "side", reactor, journal,
+            tor_manager, timing.DebugTiming(), client_version)
+
+        tor_manager.mock_calls[:] = []
+        ep = rc._make_endpoint("ws://host:4000/v1")
+        self.assertEqual(tor_manager.mock_calls,
+                         [mock.call.stream_via("host", 4000, tls=False)])
+
+        tor_manager.mock_calls[:] = []
+        ep = rc._make_endpoint("ws://host/v1")
+        self.assertEqual(tor_manager.mock_calls,
+                         [mock.call.stream_via("host", 80, tls=False)])
+
+        tor_manager.mock_calls[:] = []
+        ep = rc._make_endpoint("wss://host:4000/v1")
+        self.assertEqual(tor_manager.mock_calls,
+                         [mock.call.stream_via("host", 4000, tls=True)])
+
+        tor_manager.mock_calls[:] = []
+        ep = rc._make_endpoint("wss://host/v1")
+        self.assertEqual(tor_manager.mock_calls,
+                         [mock.call.stream_via("host", 443, tls=True)])
+
 
 # TODO
 # #Send
