@@ -1,8 +1,11 @@
-from __future__ import print_function, absolute_import, unicode_literals
-import json, time
+import json
+import time
+
 from zope.interface import implementer
+
 from ._interfaces import ITiming
 
+
 class Event:
     def __init__(self, name, when, **details):
         # data fields that will be dumped to JSON later
@@ -22,18 +25,8 @@ class Event:
         return self
 
     def __exit__(self, exc_type, exc_value, exc_tb):
-        if exc_type:
-            # inlineCallbacks uses a special exception (defer._DefGen_Return)
-            # to deliver returnValue(), so if returnValue is used inside our
-            # with: block, we'll mistakenly think it means something broke.
-            # I've moved all returnValue() calls outside the 'with
-            # timing.add()' blocks to avoid this, but if a new one
-            # accidentally pops up, it'll get marked as an error. I used to
-            # catch-and-release _DefGen_Return to avoid this, but removed it
-            # because it requires referencing defer.py's private class
-            self.finish(exception=str(exc_type))
-        else:
-            self.finish()
+        self.finish()
+
 
 @implementer(ITiming)
 class DebugTiming:
@@ -47,11 +40,14 @@ class DebugTiming:
 
     def write(self, fn, stderr):
         with open(fn, "wt") as f:
-            data = [ dict(name=e._name,
-                          start=e._start, stop=e._stop,
-                          details=e._details,
-                          )
-                     for e in self._events ]
+            data = [
+                dict(
+                    name=e._name,
+                    start=e._start,
+                    stop=e._stop,
+                    details=e._details,
+                ) for e in self._events
+            ]
             json.dump(data, f, indent=1)
             f.write("\n")
         print("Timing data written to %s" % fn, file=stderr)
